==> semboottools_0.1.0.tar.gz: semboottools/README.md <==
<!-- badges: start -->
[![Lifecycle: stable](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Project Status: Active - The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Code size](https://img.shields.io/github/languages/code-size/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools)
[![Last Commit at Main](https://img.shields.io/github/last-commit/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools/commits/main)
[![R-CMD-check](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

(Version 0.1.0, updated on 2024-03-27, [release history](https://Yangzhen1999.github.io/semboottools/news/index.html))

# semboottools: Bootstrapping Helpers For Structural Equation Modelling

A collection of helper functions for
forming bootstrapping confidence
intervals and examining bootstrap
estimates in structural equation
modelling. You can learn more about this package at the
[Github page](https://Yangzhen1999.github.io/semboottools/) of this
package.

# Installation

Stable release versions of this package
can be downloaded below:

https://github.com/Yangzhen1999/semboottools/releases

The latest developmental version of this
package can be installed by `remotes::install_github`:

```r
remotes::install_github("Yangzhen1999/semboottools")
```

# Issues

If you have any suggestions and found any
bugs, please feel feel to open a GitHub
issue. Thanks.

==> semboottools_0.1.1.tar.gz: semboottools/README.md <==
<!-- badges: start -->
[![Lifecycle: Experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![Project Status: WIP - Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
[![Code size](https://img.shields.io/github/languages/code-size/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools)
[![Last Commit at Main](https://img.shields.io/github/last-commit/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools/commits/main)
[![R-CMD-check](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

(Version 0.0.0.9012, updated on 2024-03-17, [release history](https://Yangzhen1999.github.io/semboottools/news/index.html))

# semboottools: Bootstrapping Helpers For Structural Equation Modelling

A collection of helper functions for
forming bootstrapping confidence
intervals and examining bootstrap
estimates in structural equation
modelling. For more information on this
package, please visit its GitHub page:

https://Yangzhen1999.github.io/semboottools/

# Installation

Stable release versions of this package
can be downloaded below:

https://github.com/Yangzhen1999/semboottools/releases

The latest developmental version of this
package can be installed by `remotes::install_github`:

```r
remotes::install_github("Yangzhen1999/semboottools")
```

# Issues

If you have any suggestions and found any
bugs, please feel feel to open a GitHub
issue. Thanks.
